OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nebylo možné odeslat email následujícím uživatelům: %s",
    "Preparing update" : "Příprava na aktualizaci",
    "Turned on maintenance mode" : "Zapnut režim údržby",
    "Turned off maintenance mode" : "Vypnut režim údržby",
    "Maintenance mode is kept active" : "Mód údržby je aktivní",
    "Updating database schema" : "Aktualizace schéma databáze",
    "Updated database" : "Zaktualizována databáze",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Probíhá ověření, zda je možné aktualizovat schéma databáze (toto může trvat déle v závislosti na velikosti databáze)",
    "Checked database schema update" : "Aktualizace schéma databáze byla ověřena",
    "Checking updates of apps" : "Kontrola aktualizace aplikací",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Probíhá ověření, zda je možné aktualizovat schéma databáze %s (toto může trvat déle v závislosti na velikosti databáze)",
    "Checked database schema update for apps" : "Aktualizace schéma databáze aplikací byla ověřena",
    "Updated \"%s\" to %s" : "Aktualizováno z \"%s\" na %s",
    "Repair warning: " : "Upozornění opravy:",
    "Repair error: " : "Chyba opravy:",
    "Set log level to debug" : "Nastavit úroveň logování na debug",
    "Reset log level" : "Resetovat úroveň logování",
    "Starting code integrity check" : "Spouští se kontrola integrity kódu",
    "Finished code integrity check" : "Kontrola integrity kódu dokončena",
    "%s (3rdparty)" : "%s (3. strana)",
    "%s (incompatible)" : "%s (nekompatibilní)",
    "Following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
    "Already up to date" : "Je již aktuální",
    "Please select a file." : "Prosím vyberte soubor.",
    "File is too big" : "Soubor je příliš velký",
    "Invalid file provided" : "Zadán neplatný soubor",
    "No image or file provided" : "Soubor nebo obrázek nebyl zadán",
    "Unknown filetype" : "Neznámý typ souboru",
    "Invalid image" : "Chybný obrázek",
    "An error occurred. Please contact your admin." : "Došlo k chybě. Kontaktujte prosím svého administrátora.",
    "No temporary profile picture available, try again" : "Dočasný profilový obrázek není k dispozici, zkuste to znovu",
    "No crop data provided" : "Nebyla poskytnuta data pro oříznutí obrázku",
    "No valid crop data provided" : "Nebyla poskytnuta platná data pro oříznutí obrázku",
    "Crop is not square" : "Ořez není čtvercový",
    "Couldn't reset password because the token is invalid" : "Heslo nebylo změněno kvůli neplatnému tokenu",
    "Couldn't reset password because the token is expired" : "Heslo nebylo změněno z důvodu vypršení tokenu",
    "Couldn't send reset email. Please make sure your username is correct." : "Nelze odeslat email pro změnu hesla. Ujistěte se prosím, že zadáváte správné uživatelské jméno.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nelze odeslat email pro změnu hesla, protože u tohoto uživatelského jména není uvedena emailová adresa. Kontaktujte prosím svého administrátora.",
    "%s password reset" : "reset hesla %s",
    "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat email pro změnu hesla. Kontaktujte svého správce systému.",
    "Sunday" : "Neděle",
    "Monday" : "Pondělí",
    "Tuesday" : "Úterý",
    "Wednesday" : "Středa",
    "Thursday" : "Čtvrtek",
    "Friday" : "Pátek",
    "Saturday" : "Sobota",
    "Sun." : "Ne",
    "Mon." : "Po",
    "Tue." : "Út",
    "Wed." : "St",
    "Thu." : "Čt",
    "Fri." : "Pá",
    "Sat." : "So",
    "Su" : "Ne",
    "Mo" : "Po",
    "Tu" : "Út",
    "We" : "St",
    "Th" : "Čt",
    "Fr" : "Pá",
    "Sa" : "So",
    "January" : "Leden",
    "February" : "Únor",
    "March" : "Březen",
    "April" : "Duben",
    "May" : "Květen",
    "June" : "Červen",
    "July" : "Červenec",
    "August" : "Srpen",
    "September" : "Září",
    "October" : "Říjen",
    "November" : "Listopad",
    "December" : "Prosinec",
    "Jan." : "leden",
    "Feb." : "únor",
    "Mar." : "březen",
    "Apr." : "duben",
    "May." : "květen",
    "Jun." : "červen",
    "Jul." : "červenec",
    "Aug." : "srpen",
    "Sep." : "září",
    "Oct." : "íjen",
    "Nov." : "listopad",
    "Dec." : "prosinec",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Došlo k problémům při kontrole integrity kódu. Více informací…</a>",
    "Settings" : "Nastavení",
    "Saving..." : "Ukládám...",
    "Dismiss" : "Zamítnout",
    "seconds ago" : "před pár sekundami",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovení hesla byl odeslán na vaši emailovou adresu. Pokud jej v krátké době neobdržíte, zkontrolujte složku nevyžádané pošty a koš.<br>Pokud jej nenaleznete, kontaktujte svého správce systému.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše soubory jsou šifrovány. Pokud jste nepovolili klíč pro obnovení, neexistuje způsob jak získat po změně hesla vaše data zpět.<br />Pokud si nejste jisti co dělat, kontaktujte nejprve svého správce systému, než budete pokračovat. <br />Opravdu si přejete pokračovat?",
    "I know what I'm doing" : "Vím co dělám",
    "Password can not be changed. Please contact your administrator." : "Heslo nelze změnit. Kontaktujte prosím svého správce systému.",
    "No" : "Ne",
    "Yes" : "Ano",
    "Choose" : "Vybrat",
    "Error loading file picker template: {error}" : "Chyba při nahrávání šablony výběru souborů: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Chyba při nahrávání šablony zprávy: {error}",
    "read-only" : "pouze ke čtení",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} souborový konflikt","{count} souborové konflikty","{count} souborových konfliktů"],
    "One file conflict" : "Jeden konflikt souboru",
    "New Files" : "Nové soubory",
    "Already existing files" : "Již existující soubory",
    "Which files do you want to keep?" : "Které soubory chcete ponechat?",
    "If you select both versions, the copied file will have a number added to its name." : "Pokud zvolíte obě verze, zkopírovaný soubor bude mít název doplněný o číslo.",
    "Cancel" : "Zrušit",
    "Continue" : "Pokračovat",
    "(all selected)" : "(vybráno vše)",
    "({count} selected)" : "(vybráno {count})",
    "Error loading file exists template" : "Chyba při nahrávání šablony existence souboru",
    "Very weak password" : "Velmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Středně silné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Váš webový server ještě není správně nastaven pro umožnění synchronizace souborů, protože rozhraní WebDAV je pravděpodobně rozbité.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Tento webový server není správně nastaven pro rozpoznání \"{url}\". Více informací lze nalézt v naší <a target=\"_blank\" href=\"{docLink}\">dokumentaci</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Tento server nemá funkční připojení k Internetu. Některé moduly jako např. externí úložiště, oznámení o dostupných aktualizacích nebo instalace aplikací třetích stran nebudou fungovat. Přístup k souborům z jiných míst a odesílání oznamovacích emailů také nemusí fungovat. Pokud chcete využívat všechny možnosti ownCloud, doporučujeme povolit pro tento server připojení k Internetu.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Nebyla nakonfigurována paměťová cache. Pro zlepšení výkonu a dostupnosti ji prosím nakonfigurujte. Další informace lze nalézt v naší <a href=\"{docLink}\">dokumentaci</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "PHP nemá práva pro čtení v /dev/urandom, to je ale z bezpečnostních důvodů velmi doporučováno. Více informací lze nalézt v <a href=\"{docLink}\">dokumentaci</a>.",
    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Vaše verze PHP ({version}) již není <a href=\"{phpLink}\">podporována</a>. Doporučujeme aktualizovat na poslední verzi PHP pro využití vylepšení výkonu a bezpečnosti.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Konfigurace hlaviček zpětné proxy není správná nebo přistupujete na ownCloud přes důvěryhodnou proxy. Pokud přistupujete na ownCloud přes nedůvěryhodnou proxy je toto považováno za bezpečnostní problém který může útočníkovi umožnit záměnu IP adresy viděné ownCloudem. Více informací lze nalézt v naší <a href=\"{docLink}\">dokumentaci</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached je nakonfigurován jako distribuovaná cache, ale je nainstalován nesprávný PHP modul \"memcache\". \\OC\\Memcache\\Memcached podporuje pouze \"memcached\" a ne \"memcache\". Projděte si <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki popisující oba moduly</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Některé soubory neprošly kontrolou integrity. Více informací o tom jak tento problém vyřešit, lze nalézt v naší <a href=\"{docLink}\">dokumentaci</a>. (<a target=\"_blank\" href=\"{codeIntegrityDownloadEndpoint}\">Seznam neplatných souborů…</a> / <a href=\"{rescanEndpoint}\">Znovu ověřit…</a>)",
    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Váš datový adresář i vaše soubory jsou pravděpodobně přístupné z Internetu. Soubor .htaccess nefunguje. Důrazně doporučujeme nakonfigurovat webový server tak, aby datový adresář nebyl nadále přístupný, nebo přesunout datový adresář mimo prostor zpřístupňovaný webovým serverem.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP hlavička \"{header}\" není nakonfigurována ve shodě s \"{expected}\". To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP hlavička \"Strict-Transport-Security\" není nakonfigurována na minimum \"{seconds}\" sekund. Pro vylepšení bezpečnosti doporučujeme povolit HSTS dle popisu v našich <a href=\"{docUrl}\">bezpečnostních tipech</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Přistupujete na tuto stránku přes protokol HTTP. Důrazně doporučujeme nakonfigurovat server tak, aby vyžadoval použití HTTPS jak je popsáno v našich <a href=\"{docUrl}\">bezpečnostních tipech</a>.",
    "Shared" : "Sdílené",
    "Shared with {recipients}" : "Sdíleno s {recipients}",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba při sdílení",
    "Error while unsharing" : "Chyba při rušení sdílení",
    "Error setting expiration date" : "Chyba při nastavení data vypršení platnosti",
    "The public link will expire no later than {days} days after it is created" : "Veřejný odkaz vyprší nejpozději {days} dní od svého vytvoření",
    "Set expiration date" : "Nastavit datum vypršení platnosti",
    "Expiration" : "Konec platnosti",
    "Expiration date" : "Datum vypršení platnosti",
    "Choose a password for the public link" : "Zadej heslo pro tento veřejný odkaz",
    "Sending ..." : "Odesílám ...",
    "Email sent" : "Email odeslán",
    "Resharing is not allowed" : "Sdílení již sdílené položky není povoleno",
    "Share link" : "Sdílet odkaz",
    "Link" : "Odkaz",
    "Password protect" : "Chránit heslem",
    "Password" : "Heslo",
    "Allow editing" : "Povolit úpravy",
    "Email link to person" : "Odeslat osobě odkaz emailem",
    "Send" : "Odeslat",
    "Shared with you and the group {group} by {owner}" : "S Vámi a skupinou {group} sdílí {owner}",
    "Shared with you by {owner}" : "S Vámi sdílí {owner}",
    "group" : "skupina",
    "remote" : "vzdálený",
    "notify by email" : "upozornit emailem",
    "Unshare" : "Zrušit sdílení",
    "can share" : "může sdílet",
    "can edit" : "lze upravovat",
    "create" : "vytvořit",
    "change" : "změnit",
    "delete" : "smazat",
    "access control" : "řízení přístupu",
    "Could not unshare" : "Nelze zrušit sdílení",
    "Share details could not be loaded for this item." : "Detaily sdílení pro tuto položku nelze načíst.",
    "No users or groups found for {search}" : "Nebyli nalezeni žádní členové ani skupiny pro {search}",
    "An error occured. Please try again" : "Nastala chyba. Prosím zkuste to znovu",
    "Share" : "Sdílet",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Sdílejte s lidmi na ownClouds použitím syntaxe username@example.com/owncloud",
    "Share with users or groups …" : "Sdílet s uživateli nebo skupinami",
    "Share with users, groups or remote users …" : "Sdílet s uživateli, skupinami nebo vzdálenými uživateli",
    "Error removing share" : "Chyba při odstraňování sdílení",
    "Warning" : "Varování",
    "Error while sending notification" : "Chyba při odesílání upozornění",
    "Non-existing tag #{tag}" : "Neexistující tag #{tag}",
    "not assignable" : "nepřiřaditelný",
    "invisible" : "neviditelný",
    "({scope})" : "({scope})",
    "Delete" : "Smazat",
    "Rename" : "Přejmenovat",
    "Collaborative tags" : "Tagy spolupráce",
    "The object type is not specified." : "Není určen typ objektu.",
    "Enter new" : "Zadat nový",
    "Add" : "Přidat",
    "Edit tags" : "Editovat štítky",
    "Error loading dialog template: {error}" : "Chyba při načítání šablony dialogu: {error}",
    "No tags selected for deletion." : "Žádné štítky nebyly vybrány ke smazání.",
    "unknown text" : "neznámý text",
    "Hello world!" : "Zdravím, světe!",
    "sunny" : "slunečno",
    "Hello {name}, the weather is {weather}" : "Ahoj {name}, je {weather}",
    "Hello {name}" : "Vítej, {name}",
    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace, opuštění této stránky může v některých prostředích přerušit proces.",
    "Updating {productName} to version {version}, this may take a while." : "Aktualizuji {productName} na verzi {version}, může to chvíli trvat.",
    "An error occurred." : "Došlo k chybě.",
    "Please reload the page." : "Načtěte stránku znovu, prosím.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizace nebyla úspěšná. Pro více informací si <a href=\"{url}\">přečtěte komentáře ve fóru</a> pojednávající o tomto problému.",
    "The update was unsuccessful. " : "Aktualizace nebyla úspěšná.",
    "The update was successful. There were warnings." : "Aktualizace byla úspěšná. Zachycen výskyt varování.",
    "The update was successful. Redirecting you to ownCloud now." : "Aktualizace byla úspěšná. Přesměrovávám na ownCloud.",
    "Searching other places" : "Prohledávání ostatních umístění",
    "No search results in other folders" : "V ostatních adresářích nebylo nic nalezeno",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} nález v dalším adresáři","{count} nálezy v dalších adresářích","{count} nálezů v dalších adresářích"],
    "Personal" : "Osobní",
    "Users" : "Uživatelé",
    "Apps" : "Aplikace",
    "Admin" : "Administrace",
    "Help" : "Nápověda",
    "Error loading tags" : "Chyba při načítání štítků",
    "Tag already exists" : "Štítek již existuje",
    "Error deleting tag(s)" : "Chyba při mazání štítku(ů)",
    "Error tagging" : "Chyba při označování štítkem",
    "Error untagging" : "Chyba při odznačování štítků",
    "Error favoriting" : "Chyba při označování jako oblíbené",
    "Error unfavoriting" : "Chyba při odznačování jako oblíbené",
    "Access forbidden" : "Přístup zakázán",
    "File not found" : "Soubor nenalezen",
    "The specified document has not been found on the server." : "Požadovaný dokument nebyl na serveru nalezen.",
    "You can click here to return to %s." : "Klikněte zde pro návrat na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej ty tam,\n\njen ti chci dát vědět, že %s sdílel %s s tebou.\nZobraz si to: %s\n\n",
    "The share will expire on %s." : "Sdílení vyprší %s.",
    "Cheers!" : "Ať slouží!",
    "Internal Server Error" : "Vnitřní chyba serveru",
    "The server encountered an internal error and was unable to complete your request." : "Server zaznamenal interní chybu a nebyl schopen dokončit váš požadavek.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Kontaktujte prosím správce serveru, pokud se bude tato chyba opakovat. Připojte do svého hlášení níže zobrazené technické detaily.",
    "More details can be found in the server log." : "Více podrobností k nalezení v serverovém logu.",
    "Technical details" : "Technické detaily",
    "Remote Address: %s" : "Vzdálená adresa: %s",
    "Request ID: %s" : "ID požadavku: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Zpráva: %s",
    "File: %s" : "Soubor: %s",
    "Line: %s" : "Řádka: %s",
    "Trace" : "Trasa",
    "Security warning" : "Bezpečnostní varování",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář s daty a soubory jsou dostupné z internetu, protože soubor .htaccess nefunguje.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pro informace, jak správně nastavit váš server, se podívejte do <a href=\"%s\" target=\"_blank\">dokumentace</a>.",
    "Create an <strong>admin account</strong>" : "Vytvořit <strong>účet správce</strong>",
    "Username" : "Uživatelské jméno",
    "Storage & database" : "Úložiště & databáze",
    "Data folder" : "Složka s daty",
    "Configure the database" : "Nastavit databázi",
    "Only %s is available." : "Pouze %s je dostupný.",
    "Install and activate additional PHP modules to choose other database types." : "Pro výběr jiných typů databáze je třeba nainstalovat a povolit dodatečné PHP moduly.",
    "For more details check out the documentation." : "Více informací lze nalézt v dokumentaci.",
    "Database user" : "Uživatel databáze",
    "Database password" : "Heslo databáze",
    "Database name" : "Název databáze",
    "Database tablespace" : "Tabulkový prostor databáze",
    "Database host" : "Hostitel databáze",
    "Performance warning" : "Varování o výkonu",
    "SQLite will be used as database." : "Bude použita SQLite databáze.",
    "For larger installations we recommend to choose a different database backend." : "Pro větší instalace doporučujeme vybrat jiné databázové řešení.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Obzvláště při používání klientské aplikace pro synchronizaci s desktopem není SQLite doporučeno.",
    "Finish setup" : "Dokončit nastavení",
    "Finishing …" : "Dokončuji...",
    "Need help?" : "Potřebujete pomoc?",
    "See the documentation" : "Shlédnout dokumentaci",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ahoj,<br><br>jen ti dávám vědět, že s tebou %s sdílí <strong>%s</strong>.<br><a href=\"%s\">Zkontroluj to!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tato aplikace potřebuje pro správnou funkčnost JavaScript. Prosím {linkstart}povolte JavaScript{linkend} a znovu načtěte stránku.",
    "Log out" : "Odhlásit se",
    "Search" : "Hledat",
    "Server side authentication failed!" : "Autentizace na serveru selhala!",
    "Please contact your administrator." : "Kontaktujte prosím svého správce systému.",
    "An internal error occured." : "Nastala vnitřní chyba.",
    "Please try again or contact your administrator." : "Prosím zkuste to znovu nebo kontaktujte vašeho správce.",
    "Log in" : "Přihlásit",
    "Wrong password. Reset it?" : "Nesprávné heslo. Resetovat?",
    "Wrong password." : "Chybné heslo.",
    "Stay logged in" : "Neodhlašovat",
    "Alternative Logins" : "Alternativní přihlášení",
    "Use the following link to reset your password: {link}" : "Heslo obnovíte použitím následujícího odkazu: {link}",
    "New password" : "Nové heslo",
    "New Password" : "Nové heslo",
    "Reset password" : "Obnovit heslo",
    "This ownCloud instance is currently in single user mode." : "Tato instalace ownCloudu je momentálně v jednouživatelském módu.",
    "This means only administrators can use the instance." : "To znamená, že pouze správci systému mohou aplikaci používat.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správce systému, pokud se tato zpráva objevuje opakovaně nebo nečekaně.",
    "Thank you for your patience." : "Děkujeme za vaši trpělivost.",
    "You are accessing the server from an untrusted domain." : "Přistupujete na server z nedůvěryhodné domény.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontaktujte prosím svého správce. Pokud spravujete tuto instalaci, nastavte \"trusted_domains\" v souboru config/config.php. Příklad konfigurace najdete v souboru config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "V závislosti na vaší konfiguraci vám může být, jako správci, umožněno použití tlačítka níže k označení této domény jako důvěryhodné.",
    "Add \"%s\" as trusted domain" : "Přidat \"%s\" jako důvěryhodnou doménu",
    "App update required" : "Vyžadována aktualizace aplikace",
    "%s will be updated to version %s" : "%s bude aktualizován na verzi %s",
    "These apps will be updated:" : "Následující aplikace budou aktualizovány:",
    "These incompatible apps will be disabled:" : "Následující nekompatibilní aplikace budou zakázány:",
    "The theme %s has been disabled." : "Vzhled %s byl zakázán.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Před provedením dalšího kroku se prosím ujistěte, že databáze a konfigurační a datový adresář byly zazálohovány.  ",
    "Start update" : "Spustit aktualizaci",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Abyste zabránili vypršení časového limitu u větších instalací, můžete namísto toho spustit následující příkaz v hlavním adresáři:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tato instalace %s je právě ve stavu údržby a to může chvíli trvat.",
    "This page will refresh itself when the %s instance is available again." : "Tato stránka se automaticky načte poté, co bude opět dostupná instance %s."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
